# Check for status of man pages
# http://code.google.com/p/redis/issues/detail?id=202

Name:             redis
Version:          2.4.8
Release:          %mkrel 4
Summary:          A persistent key-value database

Group:            Databases
License:          BSD
URL:              http://redis.io/
Source0:          http://redis.googlecode.com/files/%{name}-%{version}.tar.gz
Source1:          %{name}.logrotate
Source2:          %{name}.init
Source3:          %{name}.service
# Update configuration for Fedora
Patch0:           %{name}-2.0.0-redis.conf.patch
Patch1:		  redis-2.4.8-extend-timeout-on-replication-test.patch
BuildRequires:    tcl >= 8.5
Requires(post):   rpm-helper >= 0.24.8-1
Requires(preun):  rpm-helper >= 0.24.8-1

%description
Redis is an advanced key-value store. It is similar to memcached but the data
set is not volatile, and values can be strings, exactly like in memcached, but
also lists, sets, and ordered sets. All this data types can be manipulated with
atomic operations to push/pop elements, add/remove elements, perform server side
union, intersection, difference between sets, and so forth. Redis supports
different kind of sorting abilities.

%prep
%setup -q
%patch0 -p0
%patch1 -p1
# Remove integration tests
sed -i '/    execute_tests "integration\/replication"/d' tests/test_helper.tcl
sed -i '/    execute_tests "integration\/aof"/d' tests/test_helper.tcl

%build
export LC_ALL=C
%make -j1 DEBUG="" CFLAGS='%{optflags} -std=c99' all FORCE_LIBC_MALLOC=yes

%check
tclsh tests/test_helper.tcl

%install
# Install binaries
install -p -D -m 755 src/%{name}-benchmark %{buildroot}%{_bindir}/%{name}-benchmark
install -p -D -m 755 src/%{name}-cli %{buildroot}%{_bindir}/%{name}-cli
install -p -D -m 755 src/%{name}-check-aof %{buildroot}%{_bindir}/%{name}-check-aof
install -p -D -m 755 src/%{name}-check-dump %{buildroot}%{_bindir}/%{name}-check-dump
install -p -D -m 755 src/%{name}-server %{buildroot}%{_sbindir}/%{name}-server
# Install misc other
install -d -m 755 %{buildroot}%{_sysconfdir}
install -m 644 %{name}.conf %{buildroot}%{_sysconfdir}/%{name}.conf
install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -d -m 755 %{buildroot}%{_initrddir}
install -m 755 %{SOURCE2} %{buildroot}%{_initrddir}/%{name}
install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service

install -d -m 755 %{buildroot}%{_localstatedir}/lib/%{name}
install -d -m 755 %{buildroot}%{_localstatedir}/log/%{name}
install -d -m 755 %{buildroot}%{_localstatedir}/run/%{name}


%post
%_post_service redis

%pre
%_pre_groupadd redis
%_pre_useradd redis  %{_sharedstatedir}/redis /sbin/nologin

%preun
%_preun_service redis

%postun 
%_postun_userdel redis
%_postun_groupdel redis

%files
%doc 00-RELEASENOTES BUGS COPYING README
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}.conf
%dir %attr(0755, redis, root) %{_localstatedir}/lib/%{name}
%dir %attr(0755, redis, root) %{_localstatedir}/log/%{name}
%dir %attr(0755, redis, root) %{_localstatedir}/run/%{name}
%{_bindir}/%{name}-*
%{_sbindir}/%{name}-*
%{_initrddir}/%{name}
%{_unitdir}/%{name}.service


%changelog

* Thu May 10 2012 colin <colin> 2.4.8-4.mga2
+ Revision: 235025
- Revert previous version bump. It was never submitted.
- New version: 2.4.11
- Add LSB headers to initscripts (mga#5262)

* Sat Apr 28 2012 tmb <tmb> 2.4.8-3.mga2
+ Revision: 234125
- extend timeout on replication test (upstream, P1)
- Require rpm-helper >= 0.24.8-1 for systemd support

* Thu Apr 12 2012 guillomovitch <guillomovitch> 2.4.8-2.mga2
+ Revision: 230441
- native systemd service
- fix dependencies

* Fri Feb 24 2012 obgr_seneca <obgr_seneca> 2.4.8-1.mga2
+ Revision: 214180
- new version 2.4.8

* Wed Sep 14 2011 tv <tv> 2.2.8-1.mga2
+ Revision: 143235
- new release

* Sun Apr 17 2011 misc <misc> 2.2.4-1.mga1
+ Revision: 87097
- update to 2.2.4, update patch  for configuration
- use parallel make
- use macros for post scripts

* Sun Apr 10 2011 dmorgan <dmorgan> 2.0.4-3.mga1
+ Revision: 82997
- Fix groups (#682)

* Sat Mar 26 2011 dmorgan <dmorgan> 2.0.4-2.mga1
+ Revision: 77616
- imported package redis


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Dec 19 2010 Silas Sewell <silas@sewell.ch> - 2.0.4-1
- Update to redis 2.0.4

* Tue Oct 19 2010 Silas Sewell <silas@sewell.ch> - 2.0.3-1
- Update to redis 2.0.3

* Fri Oct 08 2010 Silas Sewell <silas@sewell.ch> - 2.0.2-1
- Update to redis 2.0.2
- Disable checks section for el5

* Fri Sep 11 2010 Silas Sewell <silas@sewell.ch> - 2.0.1-1
- Update to redis 2.0.1

* Sat Sep 04 2010 Silas Sewell <silas@sewell.ch> - 2.0.0-1
- Update to redis 2.0.0

* Thu Sep 02 2010 Silas Sewell <silas@sewell.ch> - 1.2.6-3
- Add Fedora build flags
- Send all scriplet output to /dev/null
- Remove debugging flags
- Add redis.conf check to init script

* Mon Aug 16 2010 Silas Sewell <silas@sewell.ch> - 1.2.6-2
- Don't compress man pages
- Use patch to fix redis.conf

* Tue Jul 06 2010 Silas Sewell <silas@sewell.ch> - 1.2.6-1
- Initial package
